==> mighty_logger-0.7.0.tar.gz: mighty_logger-0.7.0/test/test.py <==
from time import sleep

from mighty_logger import Logger
from mighty_logger.src import LoggerEntryTypes, ProcessEntryTypes, LogEnvironments, IndefiniteAnimations, DefiniteAnimations

if __name__ == "__main__":
	logger = Logger(program_name="Installer", log_environment=LogEnvironments.CONSOLE, console_width=115, status_message_global_entry=False)
	logger.publish_author()

	logger.start_timer(message_text="Timer started")
	logger.entry(entry_type=LoggerEntryTypes.message, message_text="Program installation started")

	sleep(1)
	logger.start_indefinite_process(animation=IndefiniteAnimations.SuperSpace, message_text="File upload")
	sleep(2)
	logger.note_process(entry_type=ProcessEntryTypes.achievement, message_text="Files downloaded")
	sleep(3)
	logger.progress_rise(100)
	logger.stop_process(message_text="Files unzipped")

	logger.entry(entry_type=LoggerEntryTypes.warning, message_text="Newer version found")
	logger.timer_mark(message_text="Timer mark")

	logger.separator()

	data = logger.getty("Enter password: ")

	sleep(1)
	logger.start_definite_process(progress_bar=DefiniteAnimations.Arrow, message_text="Installing files")
	sleep(0.6)
	logger.progress_rise(3)
	sleep(0.4)
	logger.progress_rise(7)
	sleep(0.3)
	logger.progress_rise(14)
	sleep(0.5)
	logger.progress_rise(16)
	sleep(1.1)
	logger.progress_rise(19)
	sleep(1.5)
	logger.progress_rise(25)
	sleep(1.4)
	logger.progress_rise(35)
	sleep(1.4)
	logger.progress_rise(45)
	sleep(1.6)
	logger.progress_rise(46)
	sleep(1.1)
	logger.progress_rise(47)
	logger.note_process(entry_type=ProcessEntryTypes.milestone, message_text="Files prepared")
	sleep(3.7)
	logger.progress_rise(76)
	sleep(1.5)
	logger.progress_rise(77)
	sleep(1.4)
	logger.progress_rise(79)
	sleep(1.1)
	logger.progress_rise(81)
	sleep(1.2)
	logger.progress_rise(82)
	sleep(1.3)
	logger.progress_rise(85)
	sleep(0.8)
	logger.note_process(entry_type=LoggerEntryTypes.error, message_text="Incompatibility found")
	sleep(1.3)
	logger.note_process(entry_type=LoggerEntryTypes.resolved, message_text="Incompatibility eliminated")
	sleep(1.1)
	logger.progress_rise(86)
	sleep(0.6)
	logger.progress_rise(87)
	sleep(0.9)
	logger.progress_rise(88)
	sleep(0.9)
	logger.progress_rise(89)
	sleep(0.9)
	logger.progress_rise(90)
	sleep(1.4)
	logger.progress_rise(91)
	sleep(1.8)
	logger.progress_rise(97)
	sleep(1.5)
	logger.progress_rise(100)
	sleep(1.3)
	logger.stop_process(message_text="Program installed")

	logger.stop_timer(message_text="Timer completed")
	logger.empty(entry=data)

	logger.savy("log", False)

==> mighty_logger-0.7.2.tar.gz: mighty_logger-0.7.2/test/test.py <==
from time import sleep

from mighty_logger import MightyLogger
from mighty_logger.src.lib_types_collection import LoggerEntryTypes,\
	ProcessEntryTypes,\
	LogEnvironments,\
	SortingKeys,\
	SelectionTypes
from mighty_logger.src import IndefiniteAnimations, DefiniteAnimations

if __name__ == "__main__":
	logger = MightyLogger(program_name="Installer", log_environment=LogEnvironments.CONSOLE, console_width=115, status_message_global_entry=False)
	logger.publish_author()

	logger.start_timer(message_text="Timer started")
	logger.entry(entry_type=LoggerEntryTypes.message, message_text="Program installation started")

	sleep(1)
	logger.start_indefinite_process(animation=IndefiniteAnimations.SuperSpace, message_text="File upload")
	sleep(2)
	logger.note_process(entry_type=ProcessEntryTypes.achievement, message_text="Files downloaded")
	sleep(3)
	logger.progress_rise(100)
	logger.stop_process(message_text="Files unzipped")

	logger.entry(entry_type=LoggerEntryTypes.warning, message_text="Newer version found")
	logger.timer_mark(message_text="Timer mark")

	logger.separator()

	data = logger.getty("Enter password: ")

	sleep(1)
	logger.start_definite_process(progress_bar=DefiniteAnimations.Arrow, message_text="Installing files")
	sleep(0.6)
	logger.progress_rise(3)
	sleep(0.4)
	logger.progress_rise(7)
	sleep(0.3)
	logger.progress_rise(14)
	sleep(0.5)
	logger.progress_rise(16)
	sleep(1.1)
	logger.progress_rise(19)
	sleep(1.5)
	logger.progress_rise(25)
	sleep(1.4)
	logger.progress_rise(35)
	sleep(1.4)
	logger.progress_rise(45)
	sleep(1.6)
	logger.progress_rise(46)
	sleep(1.1)
	logger.progress_rise(47)
	logger.note_process(entry_type=ProcessEntryTypes.milestone, message_text="Files prepared")
	sleep(3.7)
	logger.progress_rise(76)
	sleep(1.5)
	logger.progress_rise(77)
	sleep(1.4)
	logger.progress_rise(79)
	sleep(1.1)
	logger.progress_rise(81)
	sleep(1.2)
	logger.progress_rise(82)
	sleep(1.3)
	logger.progress_rise(85)
	sleep(0.8)
	logger.note_process(entry_type=LoggerEntryTypes.error, message_text="Incompatibility found")
	sleep(1.3)
	logger.note_process(entry_type=LoggerEntryTypes.resolved, message_text="Incompatibility eliminated")
	sleep(1.1)
	logger.progress_rise(86)
	sleep(0.6)
	logger.progress_rise(87)
	sleep(0.9)
	logger.progress_rise(88)
	sleep(0.9)
	logger.progress_rise(89)
	sleep(0.9)
	logger.progress_rise(90)
	sleep(1.4)
	logger.progress_rise(91)
	sleep(1.8)
	logger.progress_rise(97)
	sleep(1.5)
	logger.progress_rise(100)
	sleep(1.3)
	logger.stop_process(message_text="Program installed")

	logger.stop_timer(message_text="Timer completed")
	logger.empty(entry=data)

	# logger.savy("log", False)

	logger.sort(SortingKeys.SORT_ON_TYPE)
	# logger.sort_with_save(SortingKeys.SORT_ON_TYPE)
	# logger.search("o", True)
	# logger.search_with_save("o", True)
	# logger.select(SelectionTypes.initiation)
	# logger.select_with_save(SelectionTypes.initiation)
	logger.entry(entry_type=LoggerEntryTypes.info, message_text="Logger sorted")
